import type { RouteRecordRaw } from 'vue-router'
import { Layout } from '@/router/constant'

/**
 * @param name 路由名称, 必须设置,且不能重名
 * @param meta 路由元信息（路由附带扩展信息）
 * @param redirect 重定向地址, 访问这个路由时,自定进行重定向
 * @param meta.disabled 禁用整个菜单
 * @param meta.title 菜单名称
 * @param meta.icon 菜单图标
 * @param meta.keepAlive 缓存该路由
 * @param meta.sort 排序越小越排前
 *
 */
const routes: Array<RouteRecordRaw> = [
  {
    path: '/',
    name: 'message',
    redirect: '/message',
    component: Layout,
    meta: {
      title: '消息通知',
      permissions: ['worksheet-main'],
      svgname: 'worksheet',
      svgsize: 22,
      sort: 5,
      disabled: true,
      hidden: true,
    },
    children: [
      {
        path: 'message',
        name: 'message-main',
        meta: {
          title: 'message',
        },
        component: () => import('@/views/message/index.vue'),
      },
      {
        path: 'message-detail',
        name: 'message-detail',
        meta: {
          title: 'message',
        },
        component: () => import('@/views/message/content/Detail.vue'),
      },
    ],
  },
]

export default routes
